# phyloRNN
[![Version](https://anaconda.org/bioconda/phylornn/badges/version.svg)](https://anaconda.org/bioconda/phylornn)
[![Release](https://anaconda.org/bioconda/phylornn/badges/latest_release_date.svg)](https://anaconda.org/bioconda/phylornn)
[![Build Status](https://anaconda.org/bioconda/phylornn/badges/platforms.svg)](https://anaconda.org/bioconda/phylornn)
[![install with bioconda](https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat)](http://bioconda.github.io/recipes/phylornn/README.html)

**phyloRNN** is also available as the `phylornn` conda/mamba package from the channel `bioconda`:
```bash
mamba install -c conda-forge -c bioconda phylornn
```
